package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````(ID$"#0```!<P@```````#0`(``)
M`"@`'``;``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(6*\`
M`%BO```%`````!````$```#@O@``X#X%".`^!0A(`@``M!(```8`````$```
M`@```.R^``#L/@4([#X%"!`!```0`0``!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&2PH```L"`%"+`@!0CL````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DX+X`
M`.`^!0C@/@4((`$``"`!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`8@.D[ZE'6.`B4@:1OVQ-?1R9#^<E````1`````@````(`````!P0!"5`
M!((X`4`!HH8!J,`!``)+*`0I.*(R1XH$#`A$````1@``````````````````
M`$@```!*````2P````````!,````30```$\```!0````40```%(`````````
M5```````````````50```%8```!9``````````````!:````7````%T```!?
M`````````&$```!C``````````````!E````9@```&<`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!?4&.Q</E/RSR
MV],=^J%L8+F-\0X`````````````````````]0(`````````````$@```)L#
M`````````````!(````Y`@`````````````2````$0``````````````(```
M`!<$`````````````!(```",`P`````````````2````/0$`````````````
M$@```!`#`````````````!(```#3```````````````2````_`(`````````
M````$@```*\``````````````!(````X`0`````````````2````LP(`````
M````````$@```$D#`````````````!(```#$`@`````````````2````H0$`
M````````````$@```%D#`````````````!(```!0`P`````````````2````
M80$`````````````$@```.$``````````````!(```#K`0`````````````2
M````B`$`````````````$@```(("`````````````!(````Q`@``````````
M```2````X`(`````````````$@```-@!`````````````!(```#1`@``````
M```````2````Y`$`````````````$@```&\!`````````````!(```!@`P``
M```````````2````+0``````````````(````)0"`````````````!(```!M
M`P`````````````2````>```````````````$@```.X"`````````````!(`
M``"B`P`````````````2````*@(`````````````$@````\!````````````
M`!(```"^```````````````2````E@$`````````````$@```,L"````````
M`````!(```"A`@`````````````2````4@(`````````````$@```-D"````
M`````````!(```!J```````````````2````0@$`````````````$@```!<#
M`````````````!(```#-`0`````````````2````'`$`````````````$@``
M`)0#`````````````!(```#G`@`````````````2````KP$`````````````
M$@```#P``````````````"````#S```````````````2````?P$`````````
M````$@```'0#`````````````!(````"`P`````````````2````AP``````
M````````$@```%```````````````"````"9`@`````````````2````.`,`
M````````````$@```#X"`````````````!(````E`P`````````````2````
M8P(`````````````$@```*H"`````````````!(````P`P`````````````2
M````?@,`````````````$@```$X!``!PE00(`````!(```"/!```:.$$"`0`
M```1``\`100``+#/!`A7#```$@`-`)8$```@S`0(MP$``!(`#0#N`P``5.$$
M"``````2``X`M@,``$!!!0@$````(0`9`/0#```PR00(!0```!(`#0!U!```
MX.`$"&$````2``T`G@```""6!`@`````$@```"T!``!(004(!````!$`&0!2
M!```&$$%"``````0`!@`0@,``$1!!0@$````$0`9`%0$```8004(`````"``
M&`"U`P``0$$%"`0````A`!D`Y`,``%#A!`@"````$@`-`(4$```D004(!```
M`!$`&`"K!```0,D$"+P!```2``T``@$``$Q!!0@!````$0`9`+0#``!`004(
M!````!$`&0"O`P```)<$""("```2``T`R@0``.#-!`AI````$@`-``4$``!0
MS@0()````!(`#0`@!```X-\$"'0````2``T`TP,``"A!!0@`````$``9`-\#
M``"4404(`````!``&0!S`@``;.$$"`0````1``\`]`0``!#<!`C.`P``$@`-
M`%\$``!PR`0(L0```!(`#0!8!```(ID$"``````2``T`O0$``%"3!`@`````
M$@```#D$```PRP0(Z````!(`#0#,`P``*$$%"``````0`!@`+`0```#+!`@M
M````$@`-`-@$``!@X`0(.````!(`#0"C!```\,<$""<````2``T`]@$``%!!
M!0@3````$0`9`+@$``"`S@0()@$``!(`#0"E!```E)($"``````2``L``&QI
M8G!E<FPN<V\N-2XR,`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G
M;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R
M;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T
M:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T<W!E
M8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T
M9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R
M9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E
M86QL;V,`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I
M<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T
M-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F
M7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`
M7U]E;G9I<F]N`&QI8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]E
M;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A
M<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`<&%R7V-U<G)E
M;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V9P7VAW
M`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%05)3
M5$%#2P!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR`$=,24)#7S(N
M,`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0````"``(``P``
M``(``@`"``(````"```````$``(``@````(``@````````````4`!@`"````
M`@`"````!P````(``@````(``@`&``````````(``@`#``(```````<`````
M``(``@````````````@`!P```````@`(``,`"``#``(``@`'`````0`!``$`
M`0`"``$``0```````0`"``$``@`!``$``0````(``0`!``$``0`!``$``0`!
M``$``0````$``0`!``$``0````$``0`!``(`&@(``!`````P````$FEI#0``
M!@`*!0``$````!!I:0T```,`%`4````````!``4`:0(``!``````````$FEI
M#0``"``*!0``$````'09:0D```<`'@4``!````!R&6D)```%`"H%```0````
M%&EI#0``!``V!0``$````!!I:0T```(`%`4```````#\/P4(!A\``$!!!0@%
M5@``1$$%"`5/``!(004(!4T``$Q!!0@%50``4$$%"`5G```,0`4(!P$``!!`
M!0@'`@``%$`%"`<#```80`4(!P4``!Q`!0@'!@``($`%"`<'```D0`4(!P@`
M`"A`!0@'"0``+$`%"`=A```P0`4(!PH``#1`!0@'"P``.$`%"`<,```\0`4(
M!PT``$!`!0@'#@``1$`%"`</``!(0`4(!Q```$Q`!0@'$0``4$`%"`<2``!4
M0`4(!Q,``%A`!0@'%```7$`%"`<5``!@0`4(!Q8``&1`!0@'%P``:$`%"`<8
M``!L0`4(!QD``'!`!0@'&@``=$`%"`<;``!X0`4(!QP``'Q`!0@''0``@$`%
M"`<>``"$0`4(!Q\``(A`!0@'(```C$`%"`<A``"00`4(!R(``)1`!0@'(P``
MF$`%"`<D``"<0`4(!R4``*!`!0@')@``I$`%"`<G``"H0`4(!R@``*Q`!0@'
M*0``L$`%"`<J``"T0`4(!T0``+A`!0@'*P``O$`%"`<L``#`0`4(!RT``,1`
M!0@'+@``R$`%"`<O``#,0`4(!S```-!`!0@',0``U$`%"`<R``#80`4(!S,`
M`-Q`!0@'-```X$`%"`=,``#D0`4(!S8``.A`!0@'-P``[$`%"`<X``#P0`4(
M!SD``/1`!0@'.@``^$`%"`<\``#\0`4(!ST```!!!0@'/@``!$$%"`<_```(
M004(!T````Q!!0@'00``$$$%"`="```4004(!T,``%.#[`CHLP8``('#8ZT`
M`(N#_/___X7`=`7H_@$``(/$"%O#````````````_S4$0`4(_R4(0`4(````
M`/\E#$`%"&@`````Z>#_____)1!`!0AH"````.G0_____R440`4(:!````#I
MP/____\E&$`%"&@8````Z;#_____)1Q`!0AH(````.F@_____R4@0`4(:"@`
M``#ID/____\E)$`%"&@P````Z8#_____)2A`!0AH.````.EP_____R4L0`4(
M:$````#I8/____\E,$`%"&A(````Z5#_____)31`!0AH4````.E`_____R4X
M0`4(:%@```#I,/____\E/$`%"&A@````Z2#_____)4!`!0AH:````.D0____
M_R5$0`4(:'````#I`/____\E2$`%"&AX````Z?#^____)4Q`!0AH@````.G@
M_O___R500`4(:(@```#IT/[___\E5$`%"&B0````Z<#^____)5A`!0AHF```
M`.FP_O___R5<0`4(:*````#IH/[___\E8$`%"&BH````Z9#^____)61`!0AH
ML````.F`_O___R5H0`4(:+@```#I</[___\E;$`%"&C`````Z6#^____)7!`
M!0AHR````.E0_O___R5T0`4(:-````#I0/[___\E>$`%"&C8````Z3#^____
M)7Q`!0AHX````.D@_O___R6`0`4(:.@```#I$/[___\EA$`%"&CP````Z0#^
M____)8A`!0AH^````.GP_?___R6,0`4(:``!``#IX/W___\ED$`%"&@(`0``
MZ=#]____)91`!0AH$`$``.G`_?___R680`4(:!@!``#IL/W___\EG$`%"&@@
M`0``Z:#]____):!`!0AH*`$``.F0_?___R6D0`4(:#`!``#I@/W___\EJ$`%
M"&@X`0``Z7#]____):Q`!0AH0`$``.E@_?___R6P0`4(:$@!``#I4/W___\E
MM$`%"&A0`0``Z4#]____);A`!0AH6`$``.DP_?___R6\0`4(:&`!``#I(/W_
M__\EP$`%"&AH`0``Z1#]____)<1`!0AH<`$``.D`_?___R7(0`4(:'@!``#I
M\/S___\ES$`%"&B``0``Z>#\____)=!`!0AHB`$``.G0_/___R740`4(:)`!
M``#IP/S___\EV$`%"&B8`0``Z;#\____)=Q`!0AHH`$``.F@_/___R7@0`4(
M:*@!``#ID/S___\EY$`%"&BP`0``Z8#\____)>A`!0AHN`$``.EP_/___R7L
M0`4(:,`!``#I8/S___\E\$`%"&C(`0``Z5#\____)?1`!0AHT`$``.E`_/__
M_R7X0`4(:-@!``#I,/S___\E_$`%"&C@`0``Z2#\____)0!!!0AHZ`$``.D0
M_/___R4$004(:/`!``#I`/S___\E"$$%"&CX`0``Z?#[____)0Q!!0AH``(`
M`.G@^____R40004(:`@"``#IT/O___\E%$$%"&@0`@``Z<#[__^-3"0$@^3P
M_W'\58GE5E-1B<N#[$"+002)1=2+00B)1=!EH10```")1>0QP(U%T%"-1=10
M4>BF_?__@\0,:'"5!`AH<)4$"&@@E@0(Z$])``"#Q!"`/4Q!!0@`=3'HKOS_
M_X7`HY!1!0@/A*D!``"#[`Q0Z/C[__]9_S5(004(Z!S___^#Q!#&@!T%````
M@^P,_S5(004(Z`3___^`B,X"```"6O\U2$$%".CQ_O__@(C.`@```8L#@\00
MQT7$`````(U0!8E5P-]MP-@%I"`%"-T%J"`%"-G)VNG?X)X/AP(!``"#[`S!
MX@)2Z'#\__^+==2+&X/$$*.$404(QP6(404(!````(L6@_L!QT`$2^,$",=`
M#$[C!`B)$(L5)$$%"(E0"+H!````?A*-="8`BPR6B4R0#(/"`3G:=?*#[`S'
M1)@,`````(/#`VH`4%-H(,@$"/\UD%$%".AP_?__@\0@A<")PW11@^P,_S60
M404(Z$G[__^-5>"X#^($".@,*```@\00A<!T1(/L#/\UD%$%".CG^O__Z`+]
M__^#Q!")V(MUY&4S-10```!U9(UE]%E;7EV-8?S#@^P,_S60404(Z'C]__^#
MQ!")P^N:H8Q1!0B%P'0?@^P,4.C_1@``@\00ZZ504&A0004(:+_A!`CH.?S_
M_XU5X+C$X00(Z(PG``"%P*.,404(#X1Z____Z\7H>/K__X/L#&H!Z)[[__\Q
M[5Z)X8/D\%!44FA0X00(:.#@!`A15F@`EP0(Z+W[___T9I!FD&:09I!FD&:0
MBQPDPV:09I!FD&:09I!FD+@K004(+2A!!0B#^`9V&K@`````A<!T$56)Y8/L
M%&@H004(_]"#Q!#)\\.0C70F`+@H004(+2A!!0C!^`*)PL'J'P'0T?AT&[H`
M````A=)T$E6)Y8/L$%!H*$$%"/_2@\00R?/#C70F`(V\)P````"`/6-!!0@`
M=1-5B>6#[`CH?/___\8%8T$%"`')\\-FD+CH/@4(BQ"%TG4%ZY.-=@"Z````
M`(72=/)5B>6#[!10_]*#Q!#)Z77___]FD&:0D%57,>U64X'L#`,``(E$)&B#
MP#B)="0(98L5%````(F4)/P"```QTHD$)(E\)`QFD(L$),=$['P`````QX3L
MA`````````"+5*@$BP2HB<&)QHG7P>$(P>88B=.!X0``_P`)\8G&#ZS^"('F
M`/\```G.B<&)T`^LV1@QTH'A_P```(G3"?&)QHE,['B)P<'F&,'A"('A``#_
M``G.B<$/K-D(#ZS0&('A`/\```GQ)?\````)R(F$[(````"#Q0*#_1`/A6G_
M__^-A"3@````C90DX`(``(UV`(M(W#-(!(/`"(M8T#-(I#-8^#-(E#-8H,=`
M%``````S6)")SXG>B=F)^P^LV1_!ZQ^)#"2)\8E<)`0!R0L,)(E($#G0=;J+
M1"1HBT@,BU@0BU`(BW`4BV@$BSB)3"0$BT@8B5PD"(M8'(D4)(ET)`R)3"0P
MBT@@B5PD-(M8)(GXB40D*(EL)"R)3"10`TPD>(E<)%037"1\B=J)RX'#F7F"
M6HG6@]8`B=G!X`6)\XG^B>\/K/X;B<\QTHG="<:+!"0!]XE\)!"+?"0($=6)
MQHEL)!3WUHGSBW0D,"'SB?Z+?"00(<:)="08BVPD&`G=`>^)?"0@B7PD$(L$
M)(M4)`3'1"04`````,=$)!P`````QT0D/`````#'1"1$`````(G5B<>)Q@^L
M[P+!YAZ+5"04QT0D)`````")^8M\)#")S8M,)"@)]0.\)(````");"0XBVPD
M.(G.]]:)^(G7BU0D$`69>8):(W0D""'-]]()]8GIBVPD+`'!BT0D$(G+B<;!
MX`4/K/X;BWPD*`G&`?.)7"08B5PD6(GYB>O!YQX/K-D"B?B)S8M,)`@)Q0.,
M)(@```");"1`BVPD(('!F7F"6B-4)#@C;"1`B>B)U8M4)!P)Q8M$)!@!Z8G7
MB<N)QL'@!0^L_AL)Q@'SBW0D$(E<)&")7"0@BWPD%(M4)#B)\<'F'L=$)!0`
M````QT0D3`````#'1"0\`````(G[#ZS9`HG-"?4#E"20````B6PD2(ML)%B)
MT8M4)!B!P9EY@EHC;"1(]](C5"1`B>B)U8M4)"0)Q8M$)"`!Z8G7B<N+5"1`
MB<;!X`4/K/X;BWPD',=$)!P`````"<8!\XMT)!B)7"00B5PD6(G[B?'!YAX/
MK-D"B<T)]0.4))@```");"0XBVPD8(G1BU0D(('!F7F"6B-L)#CWTB-4)$B)
MZ(G5BU0D%`G%BT0D$`'IB=>)RXG&P>`%#ZS^&XM\)"0)Q@'SBW0D((E<)&")
M7"08B?N)\<'F'@^LV0*)S0GUB6PD0(M4)$@#E"2@````BVPD6,=$)"0`````
MQT0D1`````#'1"1,`````,=$)#P`````B=&+5"00@<&9>8):(VPD0/?2(U0D
M.(GHB=6+5"0<"<6+1"08`>F)UXG+BU0D.(G&P>`%#ZS^&XM\)!3'1"04````
M``G&`?.+="00B5PD((E<)%B)^XGQP>8>#ZS9`HG-"?4#E"2H````B6PD2(ML
M)&")T8M4)!B!P9EY@EHC;"1(]](C5"1`B>B)U8M4)"0)Q8M$)"`!Z8G7B<N)
MQL'@!0^L_AN+?"0<"<8!\XMT)!B)7"1@B5PD$(G[B?'!YAX/K-D"B<T)]8EL
M)#B+5"1``Y0DL````(ML)%C'1"0<`````,=$)$0`````QT0D3`````")T8M4
M)""!P9EY@EHC;"0X]](C5"1(B>B)U8M4)!0)Q8M$)!`!Z8G7B<N+5"1(B<;!
MX`4/K/X;BWPD),=$)"0`````"<8!\XMT)"")7"08B5PD6(G[B?'!YAX/K-D"
MB<T)]0.4)+@```");"1`BVPD8(G1BU0D$('!F7F"6B-L)$#WTB-4)#B)Z(G5
MBU0D'`G%BT0D&`'IB=>)RXM4)#B)QL'@!0^L_AN+?"04"<8!\XMT)!")7"1@
MB5PD((G[B?'!YAX/K-D"B<T)]8EL)$@#E"3`````BVPD6,=$)!0`````QT0D
M/`````#'1"1$`````(G1BU0D&('!F7F"6B-L)$CWTB-4)$")Z(G5BU0D)`G%
MBT0D(`'IB=>)RXM4)$")QL'@!0^L_AN+?"0<QT0D'``````)Q@'SBW0D&(E<
M)!")7"18B?N)\<'F'@^LV0*)S0GU`Y0DR````(EL)#B+;"1@B=&+5"0@@<&9
M>8):(VPD./?2(U0D2(GHB=6+5"04"<6+1"00`>F)UXG+BU0D2(G&P>`%#ZS^
M&XM\)"0)Q@'SBW0D((E<)&")7"08B?N)\<'F'@^LV0*)S0GUB6PD0`.4)-``
M``"+;"18QT0D)`````#'1"1,`````,=$)#P`````B=&+5"00@<&9>8):(VPD
M0/?2(U0D.(GHB=6+5"0<"<6+1"08`>F)UXG+BU0D.(G&P>`%#ZS^&XM\)!3'
M1"04``````G&`?.+="00B5PD((E<)%B)^XGQP>8>#ZS9`HG-"?4#E"38````
MB6PD2(ML)&")T8M4)!B!P9EY@EHC;"1(]](C5"1`B>B)U8M4)"0)Q8M$)"`!
MZ8G7B<N+5"1`B<;!X`4/K/X;BWPD'`G&`?.+="08B5PD8(E<)!")^XGQP>8>
M#ZS9`HG-"?4#E"3@````B6PD.(G1BU0D((ML)%B!P9EY@EHC;"0XQT0D'```
M``#'1"1$`````,=$)$P`````]](C5"1(B>B)U8M4)!0)Q8M$)!`!Z8G7B<N+
M5"1(B<;!X`4/K/X;BWPD),=$)"0`````"<8!\XMT)"")7"08B5PD6(G[B?'!
MYAX/K-D"B<T)]0.4).@```");"1`BVPD8(G1BU0D$('!F7F"6B-L)$#WTB-4
M)#B)Z(G5BU0D'`G%BT0D&`'IB=>)RXM4)#B)QL'@!0^L_AN+?"04"<8!\XMT
M)!")7"1@B5PD((G[B?'!YAX/K-D"B<T)]0.4)/````");"1(B=&+5"08@<&9
M>8):]](C5"1`BVPD6"-L)$C'1"04`````,=$)#P`````QT0D1`````")Z(G5
MBU0D)`G%BT0D(`'IB=>)RXM4)$")QL'@!0^L_AN+?"0<QT0D'``````)Q@'S
MBW0D&(E<)!")7"18B?N)\<'F'@^LV0*)S0GU`Y0D^````(EL)#B+;"1@B=&+
M5"0@@<&9>8):(VPD./?2(U0D2(GHB=6+5"04"<6+1"00`>F)UXG+BU0D2(G&
MP>`%#ZS^&XM\)"0)Q@'SBW0D((E<)&")7"08B?N)\<'F'@^LV0*)S0GU`Y0D
M``$``(EL)$")T8M4)!"!P9EY@EKWTB-4)#B+;"18(VPD0,=$)"0`````QT0D
M3`````")Z(G5BU0D'`G%BT0D&`'IB=>)RXM4)#B)QL'@!0^L_AN+?"04"<8!
M\XMT)!")7"0@B5PD6(G[B?'!YAX/K-D"B<V+3"0\QT0D/``````)]0.4)`@!
M```3C"0,`0``B6PD2(ML)&")RXG1BU0D&('!F7F"6H/3`"-L)$@Q__?2(U0D
M0(GHB=6+5"0D"<6+1"0@`>D1^XG7,=*)QL'@!0^L_AN+?"0<QT0D'``````)
MQHGPB=Z)RP'#$=:)7"1@B5PD.(ET)&2+="08B?N+5"1`B?'!YAX/K-D"B<T)
M]8EL)&R);"08`Y0D$`$``(MT)%B+1"0XQT0D%`````")T8M4)""!P9EY@EHA
M[HML)&SWTB-4)$@)\HG&`=&+5"0\P>`%B<N)UXM4)$@/K/X;BWPD)`G&`?.+
M="0@B5PD0(E<)!")^XGQP>8>#ZS9`HGPB<X)Q@.4)!@!``")="0@B="+5"04
M!:'KV6XQ]8GNBVPD8(G7BU0D/#'UB>D!P8M$)!")RXG&P>`%B40D2(ML)$@/
MK/X;BT0D.`GU`>LQ_XML)$")WHE<)$B)P8G3P>`>BU0D&`^LV0*)RPG#`Y0D
M(`$``(E<)#B)T(GZ!:'KV6XS7"0@,=V)Z0'!B?`/K-`;B40D&(GPBVPD&,'@
M!8E$)$`+;"1`BU0D$,=$)!P``````>F)3"08B4PD0(M,)!0/K,H"BTPD$(G0
MBY0D*`$``(G%BT0D(,'A'@G-BXPD+`$``('"H>O9;HEL)""#T0")RXG1,=(!
MR!':,VPD.(E$)!")5"04BU0D2(M$)!C'1"04`````#'JB=&+5"0<`TPD$`^L
MT!N)\HE$)!"+1"08BVPD$,'@!8E$)$@+;"1(BT0D.`'IP>8>B4PD$(E,)$B)
M^0^LR@*)U0GUB[0D,`$``(EL)#B!QJ'KV6X!\(MT)"`Q[HML)$`Q]8GI`<&+
M1"00BU0D%(G+B<;!X`6)UXE$)$"+;"1`#ZS^&XM$)!B+5"0<"?7'1"0<````
M``'K,?^)WHE<)$")P8G3P>`>BY0D.`$```^LV0*)RPG#BT0D(('"H>O9;HG=
MB5PD((M<)#@!T(GZ,>N+;"1(,=V)Z0'!B?`/K-`;BU0D%(E$)!B)\(ML)!C!
MX`6)1"1("VPD2(G3BT0D$(N4)$`!```!Z8E,)!B)3"1(B<$/K-D"P>`>B<V+
MC"1$`0``"<6!PJ'KV6Z+1"0XB6PD.(/1`(G+B=$QT@'($=HS;"0@B40D$(E4
M)!2+5"1`BT0D&#'JB=&+5"0<`TPD$`^LT!N)\HE$)!"+1"08BVPD$,=$)!0`
M````P>`%B40D0`ML)$"+1"0@`>G!YAZ)3"1`B4PD$(GY#ZS*`HG5BU0D%`GU
MB[0D2`$``(EL)"")UXM4)!S'1"0<`````('&H>O9;@'PBW0D.#'NBVPD2#'U
MB>D!P8M$)!")RXG&P>`%B40D2(ML)$@/K/X;BT0D&`GU`>LQ_XG>B5PD2(G!
MB=/!X!Z+E"10`0``#ZS9`HG+"<.+1"0X@<*AZ]ENB=V)7"0XBUPD(`'0B?HQ
MZXML)$`QW8GI`<&)\`^LT!N+5"04B40D&(GPBVPD&,'@!8E$)$`+;"1`B=.+
M1"00`>F)3"1`B4PD&(G!#ZS9`HN4)%@!``#!X!Z)S8N,)%P!```)Q8M$)""!
MPJ'KV6Z);"0@@]$`B<N)T3'2`<@1VC-L)#B)1"00B50D%(M4)$B+1"08QT0D
M%``````QZHG1BU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML)!#!X`6)1"1("VPD
M2(M$)#@!Z<'F'HE,)!")3"1(B?D/K,H"B=6+5"04"?6+M"1@`0``B6PD.(G7
MBU0D'('&H>O9;@'PBW0D(#'NBVPD0#'UB>D!P8M$)!")RXG&P>`%B40D0(ML
M)$`/K/X;BT0D&`GU`>LQ_XG>B5PD0(G!B=/!X!Z+E"1H`0``#ZS9`HG+"<.+
M1"0@@<*AZ]ENB=V)7"0@BUPD.,=$)!P``````=")^C'KBVPD2#'=B>D!P8GP
M#ZS0&XM4)!2)1"08B?"+;"08P>`%B40D2`ML)$B)TXM$)!"+E"1P`0```>F)
M3"08B4PD2(G!#ZS9`L'@'HG-BXPD=`$```G%@<*AZ]ENBT0D.(EL)#B#T0")
MRXG1,=(!R!':,VPD((E$)!")5"04BU0D0(M$)!C'1"04`````#'JB=&+5"0<
M`TPD$`^LT!N)\HE$)!"+1"08BVPD$,'@!8E$)$`+;"1``>G!YAZ)3"1`B4PD
M$(GY#ZS*`HG5"?6+M"1X`0``BT0D((EL)""+5"04@<:AZ]EN`?"+="0XB=>+
M5"0<QT0D'``````Q[HML)$@Q]8GI`<&+1"00B<N)QL'@!8E$)$B+;"1(#ZS^
M&XM$)!@)]0'K,?^)WHE<)$B)P8G3P>`>BY0D@`$```^LV0*)RPG#BT0D.('"
MH>O9;HG=B5PD.(M<)"`!T(GZ,>N+;"1`,=V)Z0'!B?`/K-`;BU0D%(E$)!B)
M\(ML)!C!X`6)1"1`"VPD0(G3BT0D$(N4)(@!```!Z8E,)$")3"08B<$/K-D"
MP>`>B<V+C"2,`0``"<6!PJ'KV6Z+1"0@B6PD((/1`(G+B=$QT@'($=HS;"0X
MB40D$(E4)!2+5"1(BT0D&,=$)!0`````,>J)T8M4)!P#3"00#ZS0&XGRB40D
M$(M$)!B+;"00P>`%B40D2`ML)$B+1"0X`>G!YAZ)3"1(B4PD$(GY#ZS*`HG5
MBU0D%`GUB[0DD`$``(EL)#B)UXM4)!R!QJ'KV6X!\(MT)"`Q[HML)$`Q]8GI
M`<&+1"00B<N)QL'@!8E$)$"+;"1`#ZS^&XM$)!@)]0'K,?^)WHE<)$")P8G3
MP>`>BY0DF`$```^LV0*)RPG#BT0D(('"H>O9;HG=B5PD((M<)#@!T(GZ,>N+
M;"1(,=V)Z0'!B?`/K-`;B40D&(GPBVPD&,'@!8E$)$@+;"1(BT0D$(M4)!3'
M1"0<``````'IB=.+E"2@`0``B4PD&(E,)$B)P0^LV0+!X!Z)S8N,)*0!```)
MQ8'"H>O9;HM$)#B);"0X@]$`B<N)T3'2`<@1VC-L)"")1"00B50D%(M4)$"+
M1"08QT0D%``````QZHG1BU0D'`-,)!`/K-`;B?*)1"00BT0D&(ML)!#!X`6)
M1"1`"VPD0(M$)"`!Z<'F'HE,)!")3"18B?D/K,H"BWPD2(G5BU0D%`GUB[0D
MJ`$``(EL)$"!QJ'KV6X!\(MT)#@Q[C'WB?F)UP'!BT0D$(G+B<;!X`4/K/X;
M"<8!\S'_B5PD2(M$)!B)WHM4)!R)P<'@'HG3BY0DL`$```^LV0*)RXN,)+0!
M```)PX'"H>O9;HM$)#B)W8/1`(EL)"")RXG1,=(!R!':BUPD0(E$)!B)5"0<
MBU0D6(GPQT0D'``````QZS':B=&)^@-,)!@/K-`;BU0D%(E$)!B)\(ML)!C!
MX`6)1"0X"VPD.(G3BT0D$(N4)+@!```!Z8E,)!B)3"18B<$/K-D"P>`>B<T)
MQ8'"W+P;CXM$)$")T8M4)"");"0X`<&)T"-4)#@)Z"-$)$B)5"00BU0D'(G%
M"VPD$(M$)!@!Z0^LT!N)\HE$)!"+1"08P>`%B40D0(ML)!`+;"1`BT0D(,=$
M)!0`````QT0D)``````!Z<'F'HE,)$B)3"00B?D/K,H"B=,)\XG?BYPDP`$`
M`(G^B?J)?"1`@</<O!N/B=D!P8M$)#@)QB-T)%@APHM$)!")]8G&"=6+5"04
M`>G!X`6)1"0@BVPD((G+B=>+E"3(`0``#ZS^&XM\)!S'1"0<``````GUBW0D
M&`'KB5PD((E<)%B)^XGQP>8>BWPD0`^LV0*)\(G.BTPD2`G&BT0D.('"W+P;
MCXGSB?6)="0X`=`)^R'](=F)ZXG"B<V+1"0@"=T!ZHG1BU0D)(G&P>`%B<N)
MUXN4)-`!```/K/X;BWPD%`G&BT0D0`'SBW0D$(E<)$B)7"08B?N)\<'F'@^L
MV0*+7"0XQT0D%`````")S8M,)%@)]8'"W+P;CXG>`=`AZPGNB<*+1"08(?&)
M;"1`"=D!RHG&P>`%B=&+5"0<B40D$(ML)!")RXG7BY0DV`$```^L_AN+?"0D
MQT0D)``````)]8MT)"`!ZXML)$")7"18B5PD$(G[B?'!YAX/K-D"B?")SXM,
M)$@)QXM$)#B!PMR\&X^)_HG[B7PD.`'0">XAZR'QB<*+1"00B<T)W0'JB<;!
MX`6)T8M4)!2)1"0@BVPD((G+B=>+E"3@`0``#ZS^&XM\)!P)]8MT)!@!ZXE<
M)"")7"1(B?N)\<'F'HM\)#@/K-D"B?")SHM,)%@)QHM$)$"!PMR\&X^)\XET
M)$`!T`G[(=F)\XG"(?N)S8M$)"`)W0'JB=&+5"0DB<;!X`6)RXG7#ZS^&PG&
M`?.)7"18BW0D$(M\)!2)7"08BY0DZ`$``(M$)#B)\<'F'L=$)!P`````B?O'
M1"04``````^LV0*+7"1`B<V+3"1("?6!PMR\&X^)W@'0(>L)[HG"BT0D&"'Q
MB6PD.`G9`<J)QL'@!8G1BU0D'(E$)!"+;"00B<N)UXN4)/`!```/K/X;BWPD
M),=$)"0`````"?6+="0@`>N+;"0XB5PD$(E<)$B)^XGQP>8>#ZS9`HGPB<^+
M3"18"<>+1"1`@<+<O!N/B?Z)^XE\)$`!T`GN(>LA\8G"BT0D$(G-"=T!ZHG&
MP>`%B=&+5"04B40D((ML)"")RXG7BY0D^`$```^L_AN+?"0<"?6+="08`>N)
M7"18B5PD((G[B?'!YAX/K-D"B?")S@G&BT0D.(M\)$"+3"1(@<+<O!N/B?.)
M="0XQT0D'``````!T`G[(=F)\XG"(?N)S8M$)"`)W0'JB=&+5"0DB<;!X`6)
MRXG7BY0D``(```^L_AN+?"04QT0D%``````)QHM$)$`!\XMT)!")7"1(B5PD
M&(G[B?'!YAX/K-D"BUPD.(G-BTPD6`GU@<+<O!N/B=X!T"'K">Z)PHM$)!@A
M\8EL)$`)V0'*B<;!X`6)T8M4)!R)1"00BVPD$(G+B=>+E"0(`@``#ZS^&XM\
M)"0)]8MT)"`!ZXML)$")7"00B5PD6(G[B?'!YAX/K-D"B?")SXM,)$@)QXM$
M)#B!PMR\&X^)_HG[B7PD.`'0">XAZR'QB<*+1"00B<T)W0'JB<;!X`6)T8M4
M)!2)1"0@BVPD((G+QT0D)`````")UXN4)!`"```/K/X;BWPD',=$)!P`````
M"?6+="08`>N)7"1(B5PD((G[B?'!YAZ+?"0X#ZS9`HGPB<Z+3"18"<:+1"1`
M@<+<O!N/B?.)="1``=`)^R'9B?.)PB'[B<V+1"0@"=T!ZHG1BU0D)(G&P>`%
MB<N)UXN4)!@"```/K/X;BWPD%,=$)!0`````"<:+1"0X`?.+="00B5PD&(E<
M)%B)^XGQP>8>#ZS9`HM<)$")S8M,)$@)]8'"W+P;CXG>`=`AZPGNB<*+1"08
M(?&);"0X"=D!RHG&P>`%B=&+5"0<B40D$(ML)!")RXG7BY0D(`(```^L_AN+
M?"0D"?6+="0@`>N)7"1(B5PD$(G[B?'!YAX/K-D"B?")SPG'BT0D0(ML)#B+
M3"18@<+<O!N/B?Z)^XE\)$#'1"0D``````'0">XAZR'QB<*+1"00B<T)W0'J
MB<;!X`6)T8M4)!2)1"0@BVPD((G+B=>+E"0H`@``#ZS^&XM\)!S'1"0<````
M``GUBW0D&`'KB5PD6(E<)"")^XGQP>8>BWPD0`^LV0*)\(G.BTPD2`G&BT0D
M.('"W+P;CXGSB70D.`'0"?LAV8GSB<(A^XG-BT0D(`G=`>J)T8M4)"2)QL'@
M!8G+B=>+E"0P`@``#ZS^&XM\)!0)QHM$)$`!\XMT)!")7"08B5PD2(G[B?'!
MYAX/K-D"BUPD.(G-BTPD6`GU@<+<O!N/B=X!T"'K">Z)PHM$)!@A\8EL)$`)
MV0'*B<;!X`6)T8M4)!R)1"00BVPD$(G+QT0D%`````")UXN4)#@"```/K/X;
MBWPD),=$)"0`````"?6+="0@`>N+;"1`B5PD6(E<)!")^XGQP>8>#ZS9`HGP
MB<^+3"1("<>+1"0X@<+<O!N/B?Z)^XE\)#@!T`GN(>LA\8G"BT0D$(G-"=T!
MZHG&P>`%B=&+5"04B40D((ML)"")RXG7BY0D0`(```^L_AN+?"0<QT0D'```
M```)]8MT)!@!ZXE<)"")7"1(B?N)\<'F'HM\)#@/K-D"B?")SHM,)%@)QHM$
M)$"!PMR\&X^)\XET)$`!T`G[(=F)\XG"(?N)S8M$)"`)W0'JB=&+5"0DB<;!
MX`6)RXG7BY0D2`(```^L_AN+?"04"<8!\XMT)!")7"18B5PD&(G[BT0D.,=$
M)!0`````B?'!YAX/K-D"BUPD0(G-BTPD2`GU@<+<O!N/B=X!T"'K">Z)PHM$
M)!@A\8EL)#@)V0'*B<;!X`6)T8M4)!R)1"00BVPD$(G+B=>+E"10`@``#ZS^
M&XM\)"3'1"0D``````GUBW0D(`'KBVPD.(E<)$B)7"00B?N)\<'F'@^LV0*)
M\(G/BTPD6`G'BT0D0('"W+P;CXG^B?N)?"1``=`)[B'K(?&)PHM$)!")S0G=
M`>J)QL'@!8G1BU0D%(E$)""+;"0@B<N)UXN4)%@"```/K/X;BWPD'`GUBW0D
M&`'KBVPD2(E<)"")7"18B?N)\<'F'@^LV0*)\(G."<:+1"0X@<+6P6+*B70D
M&`'0,W0D0#'UB>D!P8M$)""+5"0DB<O'1"0<`````(G7B<;!X`4/K/X;BU0D
M%,=$)!0`````"<:+1"00`?,Q_XE<)$B)WHG3B<&+E"1@`@``P>`>#ZS9`HM<
M)!B)S0G%BT0D0('"UL%BRHEL)#@!T#'KBVPD6(GZ,=V)Z0'!B?`/K-`;BU0D
M)(E$)!")\(ML)!#!X`6)1"1`"VPD0(G3BT0D((N4)&@"```!Z8E,)!")3"1`
MB<$/K-D"P>`>B<T)Q8M$)!B!PM;!8LJ);"0@`=`S;"0XBU0D%#-L)$B)Z0'!
MBT0D$`^LT!N)\HE$)!B+1"00BVPD&,'@!8E$)$@+;"1(`>G!YAZ)3"1(B4PD
M&(GY#ZS*`HGPB=:+E"1P`@``BVPD0`G&BT0D.(ET)#B!PM;!8LH!T#-T)""+
M5"0<B=>+5"04QT0D%``````Q]8GI`<&+1"08B<N)QL'@!0^L_AL)QHM$)!`!
M\S'_B=Z)7"1`B=.)P8N4)'@"``#!X!X/K-D"BUPD.(G-"<6+1"0@@<+6P6+*
MB6PD(`'0,>N+;"1(B?HQW8GI`<&)\`^LT!N+5"0<B40D$(GPBVPD$,'@!8E$
M)$@+;"1(B=.+1"08BY0D@`(```'IB4PD$(E,)$B)P0^LV0+!X!Z)S0G%BT0D
M.('"UL%BRHEL)#@!T#-L)""+5"04,VPD0(GI`<&+1"00#ZS0&XGRB40D&(M$
M)!#!X`6)1"1`BVPD&`ML)$#'1"0<``````'IP>8>BVPD2(E,)$")3"08B?D/
MK,H"B?")UHN4)(@"```)QHM$)"")="0@@<+6P6+*`=`S="0XBU0D'(G7BU0D
M%,=$)!0`````,?6)Z0'!BT0D&(G+B<;!X`4/K/X;"<:+1"00`?,Q_XG>B5PD
M2(G3B<&+E"20`@``P>`>#ZS9`HM<)"")S0G%BT0D.('"UL%BRHEL)#@!T#'K
MBVPD0(GZ,=V)Z0'!B?`/K-`;BU0D'(E$)!")\(ML)!#!X`6)1"1`"VPD0(G3
MBT0D&(N4))@"```!Z8E,)$")3"00B<$/K-D"P>`>B<T)Q8M$)""!PM;!8LJ)
M;"0@`=`S;"0X,VPD2(M4)!3'1"0<`````(GI`<&+1"00#ZS0&XGRB40D&(M$
M)!"+;"08P>`%B40D2`ML)$@!Z<'F'HML)$")3"1(B4PD&(GY#ZS*`HGPB=:+
ME"2@`@``"<:+1"0XB70D.('"UL%BR@'0,W0D((M4)!R)UXM4)!3'1"04````
M`#'UB>D!P8M$)!B)RXG&P>`%#ZS^&PG&BT0D$`'S,?^)WHE<)$")TXG!BY0D
MJ`(``,'@'@^LV0*+7"0XB<T)Q8M$)""!PM;!8LJ);"0@`=`QZXML)$B)^C'=
MB>D!P8GP#ZS0&XE$)!")\(ML)!#!X`6)1"1("VPD2`'IB4PD2(E,)!"+1"08
MBU0D',=$)!P`````B=.)P8N4)+`"```/K-D"P>`>B<T)Q8M$)#B!PM;!8LJ)
M;"0X`=`S;"0@BU0D%#-L)$")Z0'!BT0D$`^LT!N)\HE$)!B+1"00BVPD&,'@
M!8E$)$`+;"1``>G!YAZ+;"1(B4PD0(E,)!B)^0^LR@*)\(G6BY0DN`(```G&
MBT0D((ET)""!PM;!8LH!T#-T)#B+5"0<B=>+5"04,?6)Z0'!BT0D&(G+B<;!
MX`4/K/X;"<:+1"00`?,Q_XG>B5PD2(G3B<&+E"3``@``P>`>#ZS9`HM<)"")
MS0G%BT0D.('"UL%BRHEL)#@!T#'KBVPD0(GZ,=V)Z0'!B?`/K-`;B40D$(GP
MP>`%B40D0(ML)!`+;"1`BT0D&(M4)!S'1"04`````,=$)!P``````>F)TXN4
M),@"``")3"00B4PD0(G!#ZS9`L'@'HG-"<6+1"0@@<+6P6+*B6PD(`'0,VPD
M.(M4)!0S;"1(B>D!P8M$)!`/K-`;B?*)1"08BT0D$(ML)!C!X`6)1"1("VPD
M2`'IP>8>BVPD((E,)!B)3"1(B?D/K,H"B?")UHN4)-`"```)QHM$)#B)="0X
M@<+6P6+*`=`Q]8M4)!R)[HML)$")UXM4)!0Q]8GI`<&+1"08B<N)QL'@!0^L
M_AL)QHM$)!`!\S'_B=Z)7"18B=.)P8N4)-@"``#!X!X/K-D"B<V+C"3<`@``
MQT0D)``````)Q8'"UL%BRHM$)"");"1`@]$`B<N)T3'2`<@1VHM<)#@QZXML
M)$@QW3';B>D!P8GP$=.)^@^LT!LQTHE$)!")\(ML)!#!X`6)1"0@"VPD((M$
M)!@!Z1'3B<J)P8E4)"")5"1(P>`>BU0D'(E<)$R)TXN4).`"```/K-D"B<V+
MC"3D`@``"<6!PM;!8LJ+1"0XB6PD&(/1`(G+B=$QT@'($=HS;"1`,=LS;"18
MB>D!P8M$)"`1TXM4)"0/K-`;BU0D)(E$)!"+1"0@BVPD$`^DP@7!X`6)1"0X
M"VPD.(E4)#PQT@'I$=.)RHGYB50D6(E4)!")\@^LR@+!YAZ)7"1<QT0D%```
M``")\(G6BY0DZ`(```G&BT0D0(ML)$B)="0X@<+6P6+*`=`S="08BU0D%(G7
MBU0D)#'UB>D!P8M$)!")TXM4)!")QL'@!0^L_AL)QHGP`<@Q_XG&BT0D((G!
MP>`>#ZS9`HM<)!2)S8M,)!0)Q8M$)!B);"1(#ZS*`L'I`HE,)"2+3"00B50D
M((N4)/`"```/I,L>P>$>@<+6P6+*B5PD%(M<)#@!T(E,)!")^C'KBVPD6#'=
MB>D!P8GP#ZS0&\'J&XE$)!B)5"0<B?")^HML)!@/I,(%P>`%B40D0`ML)$")
M5"1$B>@!R(G!`TPD*(M$)&B)P\=`!`````")"(L$)(ML)"#'0PP`````QT,4
M`````,=#'``````!\`ML)!#'0R0`````B4,(B>@#1"0(B4,0BT0D2`-$)#")
M0QB+1"0X`T0D4(E#((N$)/P"``!E,P44````=0N!Q`P#``!;7E]=P^@-T___
MC;8`````C;PG`````(7`#X2;````55=64X/L'(L-0$$%"(7)B4PD"'15#[8(
M@/D]=%N$R717B<.#PP$/M@N`^3UT!(3)=?$IPXM,)`B+*87M="R)5"0,B<:)
MSV:0@^P$4U95Z)75__^#Q!"%P'4'@'P=`#UT'X/'!(LOA>UUWH/$'#'`6UY?
M7<.-="8`,=OKN(UT)@")^BM4)`B+1"0,P?H"B1"#Q!R-1!T!6UY?7<,QP,.-
M=@"-O"<`````4XG#@^P89:$4````B40D##'`C50D"(G8Z#/___^%P'0ZC;0F
M`````*%`004(BU0D"(T4D(M*!(7)B0ITU8UV`(/"!(M*!(7)B0IU](U4)`B)
MV.CY_O__A<!US8M$)`QE,P44````=06#Q!A;P^C>T?__C;0F`````(V\)P``
M``!55XG'5E.)TX/L.&6A%````(E$)"@QP#'`@#H]#Y3``<-3Z`G3__^#Q!")
MQ8GXC50D&.B9_O__A<")Q@^$]P```(/L#%#HYM+__X/$$#G%#X;+````BT0D
M&(T,A0`````/M@<\/0^$@P$``(3`#X1[`0``B?CK#8GVC;PG`````(32=`N#
MP`$/MA"`^CUU\2GXC40H`H/L#(LU0$$%"%`!SN@:TO__@\00A<")!@^$3@$`
M`*%`004(BU0D&(U/`8L4D`^V!X3`B`)U%>L7C78`@\$!#[9!_X/"`83`B`)T
M!#P]=>S&`CTQP(VT)@`````/M@P#B$P"`8/``83)=?$QP(M\)!QE,ST4````
M#X7Y````@\0L6UY?7<.-M@````"#PP$/MD/_@\8!A,"(1O]U[^O,D(UT)@"+
M%4!!!0B+`H7`#X2M````,?:-M@````"#Q@&+!+*%P'7VC02U"````(L-@%$%
M"(7)=#6#[`A04N@[T?__@\00A<"C0$$%"`^$?````(T,M0````#'1+`$````
M`(ET)!CIP_[__XUV`(E4)`B#[`S'!8!1!0@!````4.@)T?__@\00A<!T0XT,
MM0````"#[`11BU0D$(E,)!12B40D%%#H=,___XM$)!B#Q!"+3"0,HT!!!0CK
MGC'`Z9S^__^X"````#'VZ6#___^X_____^GV_O__Z,#/__]55U93B<:![(P`
M``!EH10```")1"1\,<"%]G0%@#X`=1^+1"1\93,%%`````^%'P$``('$C```
M`%M>7UW#C78`@^P,5NC'TO__@\00A<")QW3/C;8`````@^P,5^@?TO__@\00
MA<")PP^$N@```(![$RX/A(@```"#[`R-:Q-6Z)S0__^)+"2)1"0<Z)#0__^+
M3"0<C40!`HD$).@0T/__B<-86E56:'#A!`AJ_VH!4^AKTO__@\0<C40D(%!3
M:@/H^]'__X/$$(/X_W00BT0D+"4`\```/0!```!T:X/L#%/H^L[__X/$$(/L
M#%/H7L[__X/$$.E>____C;8`````#[9#%(3`#X1,____/"X/A63___^`>Q4`
M#X0Z____Z57___^0C70F`(/L#%?HS]'__XDT).A7SO__@\00Z>#^__^-M"8`
M````B=CHL?[__^N8Z&K.__^-=@"-O"<`````5E.#[!#_-4A!!0CH8-'__XN`
M@````%N+<`3_-4A!!0CH2]'__P^V6&58_S5(004(@^-_Z#C1__^+0`0/MT`0
MP>`'"<-FB5X"6/\U2$$%".@<T?__BX"`````BU@$6/\U2$$%".@'T?__@\0,
M:@!H1>,$"%#H=\___XE#'%C_-4A!!0CHZ-#__XN`@````(M8!%C_-4A!!0CH
MT]#__XN`T`,``(E#(%C_-4A!!0CHOM#__XN`@````%J+6`3_-4A!!0CHJ=#_
M_XN(\````(/$$#'2A<ET&H/L#/\U2$$%".B,T/__BX#P````@\00BU!P@^P,
MB5,D_S5(004(Z&_0__^+@(````"+0`3'0"@`````6/\U2$$%".A3T/__BX"`
M````BT`$QT`8`````%K_-4A!!0CH-]#__XN`@````%F+6`3_-4A!!0CH(M#_
M_XN`_`$``(E#+(/$%%M>PXUV`%.)PX/L%/\U2$$%".C_S___C9#\````@\0,
M4E-J`^C]S___@\00A<!T#H/$"#'`6\.-M"8`````@^P,_S5(004(Z,K/__^+
M@`P!``"#Q!`E`/```#T`0```=".#[`S_-4A!!0CHI\___XN`#`$``(/$$"4`
M\```/0"@``!UK(/L"&H"4^C7SO__@\00A<`/E,"#Q`@/ML!;PXVT)@````!5
M5XG'5E.)U8'L(!```&6A%````(F$)!`0```QP&C_#P``C70D%%9H=N$$".A_
MS/__@\00A<!^8(U8_X!\'`P`=$Z)PX/L!%-J+U;H$,[__X/$$(7`=$&#[`S_
M-4A!!0CH"\___U-65U#HDL[__X/$((N$)`P0``!E,P44````=36!Q!P0``!;
M7E]=PXUT)@"%VW6PC70F`(/L#/\U2$$%".C*SO__@\0,55=0Z`_,__^#Q!#K
MN^BER___D(UT)@"#[!C_-4A!!0CHHL[__VAVXP0(:%"3!`AHA>$$"%#H+<W_
M_X/$+,.)]HV\)P````"#[!C_-4A!!0CH<L[__XD$).BZ____6/\U2$$%".A>
MSO__6EEJ`&A%XP0(:$7C!`AH$-P$"&BAX00(4.B`S?__@\0LPXVV`````(V_
M`````%=64X'L$"```&6A%````(F$)`P@```QP.C#R___@^P(:('A!`A0:+;A
M!`AH`1```&H!C5PD)E/H1,[__X/$((7`>&6#[`1H`!```(V\)!,0``!74^@7
MR___@\00A<")QGA&C4`!@^P,4.BBR___@\00A<")PW0Q@^P$5E=0Z#[*___&
M!#,`@\00B=B+E"0,(```93,5%````'41@<00(```6UY?PXUV`#'`Z]_H;\K_
M_^L-D)"0D)"0D)"0D)"0D.D[____C70F`(V\)P````!55U93@>PL$```BYPD
M0!```(U4)!B+O"1$$```9:$4````B80D'!```#'`N,3A!`CH&_?__X/L"(G&
M:B]3Z$[+__^#Q!"%P'0MB=JXS>$$".@K^/__B=B+C"0<$```93,-%`````^%
M3`$``('$+!```%M>7UW#@^P,4^@QR___6EF)1"04:-KA!`A7Z##,__^#Q!")
MQ8M$)`R-?"0<@\`!B40D#(UT)@"%[72=@'T``'4%O<+A!`B%]G05@^P(55;H
MV\C__X/$$(7`#X2?````@^P,5>C7RO__@\00@'P%_R]U%)"-="8`@^@!@'P%
M_R_&1`4``'3QBTPD#(T4`8'Z_P\```^//____X/L!%-HW.$$"%5H`.,$"&@`
M$```:@%7Z(K,__^#Q!3_-4A!!0CH+,S__X/$#`7\````4%=J`^@+S/__@\00
MA<!U(X/L#/\U2$$%".@&S/__BX`,`0``@\00)0#P```]`(```'09@^P(:-KA
M!`AJ`.A"R___@\00B<7I(/___X/L"&H!5^@=R___@\00A<!UU8GZN,WA!`CH
MVO;__X/L#%?H<<K__X/$$.F@_O__Z)3(__^-="8`BT0D!`^V"(3)=""-4`'K
M"@^V"H/"`83)=!&`^2]U\0^V"HG0@\(!A,EU[_/#C78`4X/L&(M<)""%VW1<
M#[83A-)T58A4)`^#[`Q3Z*#)__^-1`/_@\00#[94)`\YPW(/ZRJ-M@````"#
MZ`$YV'0=@#@O=/3K#XUV`(V\)P````"`."]T0(/H`3G#<O0YPW4U@/HO=7*-
M=@"#[`QJ`NC>R/__@\00A<!T5[HN````9HD0@\086\.-=@"-O"<`````@#@O
M=0>#Z`$YPW+T*=B-4`*!^@`0``!W)X/``6@`$```4%-H@$$%".C3R?__@\00
MN(!!!0B#Q!A;PXVV`````(/$&#'`6\/'1"0@W.$$"(/$&%OI2,G__Y"-M"8`
M````5U:#[#1EH10```")1"0L,<"A5.,$"(E$)`JA6.,$"(E$)`ZA7.,$"(E$
M)!*A8.,$"(E$)!:A9.,$"(E$)!JA:.,$"(E$)!ZA;.,$"(E$)"*A<.,$"(E$
M)"8/MP5TXP0(9HE$)"JXWN$$".BQ]/__N.?A!`CHI_3__[COX00(Z)WT__^X
M^.$$".B3]/__N/_A!`CHB?3__[@/X@0(Z'_T__^XQ.$$".AU]/__N!OB!`CH
M:_3__[@EX@0(Z&'T__^X+^($".A7]/__N,WA!`CH3?3__[@YX@0(Z$/T__^X
M0N($".@Y]/__C50D!+A-X@0(Z'OS__^%P'0,B<*X)>($".B;]/__C50D!+A>
MX@0(Z%WS__^%P'0,B<*X<.($".A]]/__C50D!+A[X@0(Z#_S__^%P'0SB<*X
MQ.$$".A?]/__NJ?B!`BX_^$$".A0]/__BT0D+&4S!10```!U58/$-%Y?PY"-
M="8`C50D!+B+X@0(Z/KR__^%P'06B<*X&^($".@:]/__Z[F0C;0F`````(UT
M)!N_G.($"+D*````\Z9UGXU4)"6X&^($".CP\___ZX_HN<7__XGVC;PG````
M`(/L'&6A%````(E$)`PQP*$@004(@_C_=!>+3"0,93,-%````'4^@\0<PXVV
M`````(U4)`BX&^($".AR\O__A<!T'@^V$(32#Y7`@/HP#Y7"#[;2(="C($$%
M".N]C70F`#'`Z_'H1\7__XVT)@````"#[`SH2,7__X/L#%#HG\3__X/$$(7`
M=`B+`(/$#,-FD#'`Z_:-M@````"-OP````!55[^SX@0(5E.[J>($"(/L3(ML
M)&#'1"0@L^($"(UT)"AEH10```")1"0\,<#'1"0DJ>($",=$)"BVX@0(QT0D
M+*SB!`C'1"0PL>($",=$)#3#X@0(QT0D.`````#K(Y"#[`A54(E$)!CHXL/_
M_X/$$(7`=$N%VW0JBP:)WX/&!(G#C50D'(GXZ(/Q__^%P'0%@#@`=<J)ZHGX
MZ*'R__^%VW76BT0D/&4S!10```!U<8/$3%M>7UW#D(VT)@````"#[`Q5Z*?%
M__^+3"08B40D'(D,)(E,)!CHD\7__XM4)!R-1`("B00DZ!/%__^#Q`R+3"0,
M46C:X00(56@`XP0(:O]J`5")1"0HZ&+'__^#Q""+5"0(B?CH)/+__^E4____
MZ.K#__^-=@"-O"<`````55=64X'L'($``(N$)#"!``"-5"0<QT0D(-KB!`C'
M1"0DPN$$",=$)"@`````QT0D.'#B!`C'1"0\:>($"(D$),=$)$#?X@0(9:$4
M````B80D#($``#'`N,3A!`C'1"1$AN($",=$)$CGX@0(QT0D3`````#'1"0L
MSN($",=$)##KX@0(QT0D-`````#H3_#__X7`=`F`.``/A?(#``#H_?W__X7`
MB<,/A`0$``"#[`Q3Z(K$__^-1``!@\00@^P,4.@*Q/__@\00@#L`B<:)QW0J
MC;8`````#[8#@^P,@\,!4&CTX@0(:O]J`5>#QP+H3,;__X/$((`[`'7<C7PD
M/+APX@0(ZQ.)]HV\)P````"#QP2+1_R%P'0VC50D'.B][___A<")PW3G@#@`
M=.+HK?7__X7`=-F#[`Q3Z'#$__^#Q!"%P(G%=5F-M"8`````BUPD((7;=$B`
M.P"_`0```'46ZSR-="8`BUR\((7;=#"#QP&`.P!T*(G8Z&'U__^%P'3E@^P,
M4^@DQ/__@\00A<!TU8G%ZPN)]HV\)P`````Q[8/L#(GS5>B3P___@\00BPN#
MPP2-D?_^_O[WT2'*@>*`@("`=.GWPH"```!U!L'J$(/#`@#2@]L#@^P,*?.-
MG`,$!```4^CDPO__B40D&%:)QFCYX@0(:-SA!`A5:/[B!`AJ_VH!4.@SQ?__
M@\0H:,`!``!6Z(7#__^#Q!"#^/]T;8/L#/\U2$$%".B_Q/__@\0,!?P```!0
M_W0D$&H#Z+O$__^#Q!"%P'1L@^P,_W0D%(M$)!#_,&B\XP0(:@'_-41!!0CH
M1<3__X/$(#'`BXPD#($``&4S#10````/A<X)``"!Q!R!``!;7E]=PY#H.\/_
M_XL`@_@1=(>#[`A0_W0D%(M$)!#_,&B`XP0(ZZV-M"8`````@^P,_S5(004(
MZ"K$__^+@`P!``"#Q!`E`/```#T`0```#X5M____@^P,_S5(004(Z`/$__^+
ML!0!``#H^,#__X/$$#G&#X5)____@^P,_S5(004(Z-_#__^+@`P!``"#Q!`E
M_P$``#W``0``#X4B____@^P,4^B=P?__C50D+(E$)!RXK.($".B;[?__@\00
MA<`/A.`(``"#[`Q0Z%?"__]=6E"+1"0,_S#H*?;__X/$$(7`B<,/A+P(``"#
M[`Q3Z,/!__^#Q!"#^`-^*XUT`_R_!^,$"+D%````\Z9U&8/X!`^$_@8``(!\
M`_LO#X3S!@``D(UT)@#H>_K__X7`=1J#[`AJ`%/HG,'__XE$)!"#Q!"%P`^%
M+0$``+JGX@0(N!OB!`@QV^@L[O__Z+?`__]H1>,$"%!HW.$$"(M\)!17:"#C
M!`AJ_VH!BW0D*%;H-,/__X/$(.L[C;0F`````.BSP?__@S@1=4#H><#__X/#
M`8/L#&A%XP0(4U!HW.$$"%=H+N,$"&K_:@%6Z/?"__^#Q#"#[`AHP`$``%;H
M1L'__X/$$(/X_W2V@^P,_W0D%.@"O___BW0D'+C$X00(B?+HDNW__XDT).A*
M^O__@\00B?#IX/W__X/L#%")1"08Z#/Z__^+1"08B00DZ`?!__^#Q!#IO_W_
M_[C.X@0(O@$```#K#HUV`(M$M"R#Q@&%P'0IC50D'.@,[/__A<!TZ(`X`'3C
M@^P,4.C*P/__@\00A<!TTXG#Z;G[__^P#;O3X@0(Z;W[__]J`FK_:NZ+="0,
M5NB`O___@\0,:@:-A"04`0``4%;H';[__X/$$("\)`P!````=0Z`O"0-`0``
M0P^$8P8``&H`:@!J`/]T)`SH0[___\=$)&`!(T5GQT0D9`````#'1"1HB:O-
M[\=$)&P`````QT0D</[<NIC'1"1T`````,=$)'AV5#(0QT0D?`````#'A"2`
M````\.'2P\>$)(0`````````QX0DB`````````#'A"2,`````````,>$))``
M````````QX0DE`````````#'A"38`````````(/$$(UV`(/L!&@`@```C80D
M%`$``%#_="0,Z$>]__^#Q!"%P(G%#X[S`0``BTPD>(M<)'R)Z(GOP>`#B>[!
M_Q\!R(/[``^'NP$``#G!#X>S`0``BXPD@````(N<)(0````/K/X=B40D>(N$
M),@```#![QT!\<=$)'P`````$?N)C"2`````A<")G"2$````#X1A`0``ND``
M``")[RG".=5^`HG7C80$B````(/L!%>-C"04`0``45#HZ;S__XN$)-@````!
M^(F$)-@```"#Q!"#^$`/A2W___^-A"0,`0``*?T!QXU$)%#HJ</__XGVC;PG
M`````(/]/P^.TP```(GNB?N-=@"+`X/N0(/#0(F$)(@```"+0\2)A"2,````
MBT/(B80DD````(M#S(F$))0```"+0]")A"28````BT/4B80DG````(M#V(F$
M)*````"+0]R)A"2D````BT/@B80DJ````(M#Y(F$)*P```"+0^B)A"2P````
MBT/LB80DM````(M#\(F$)+@```"+0_2)A"2\````BT/XB80DP````(M#_(F$
M),0```"-1"10Z.+"__^#_C\/CTG___^#[4")Z,'H!HU0`<'@!BG%P>(&`==J
M1%57C80DE````%#H,[W__XFL)-@```"#Q!#I%/[__XUT)@"-O"0,`0``Z?3^
M__^-="8`BXPD@````(N<)(0```"#P0&#TP#I0O[__X/L#/]T)`SH"[___XN$
M))````"+E"24````BYPDB````(NT)(P```")1"00B50D%(G8B?(/K-`#B<*#
MXC^-0@'&A!28````@(/$$(/X.`^/D0(``+@W````C8P4@0```"G0@_@$C5$(
M#X/``@``A<!T#*@"QD$(``^%PP,``(L\)(ML)`2(G"3'````B>J)^`^LT!B)
MZHB$),````")^`^LT!")ZHVL).,```"(A"3!````B?@/K-`(B?*(A"3"````
MB?B-O"30````B(0DPP```(G8#ZS0&(GRB(0DQ````(G8#ZS0$(GRB(0DQ0``
M`(G8#ZS0"(B$),8```"-1"10Z''!__^+1"10BU0D5(G!B=.(A"32````#ZS9
M&(G3B<Z(C"3/````B<$/K-D0B=.(C"30````B<$/K-D(BUPD7(B,)-$```"+
M3"18B=J)R(B,)-8````/K-`8B=J(A"33````B<@/K-`0B=J+7"1DB(0DU```
M`(G(BTPD8`^LT`B)VHB$)-4```")R(B,)-H````/K-`8B=J(A"37````B<@/
MK-`0B=J+7"1LB(0DV````(G(BTPD:`^LT`B)VHB$)-D```")R(B,)-X````/
MK-`8B=J(A"3;````B<@/K-`0B=J+7"1TB(0DW````(G(BTPD<`^LT`B)VHB$
M)-T```")R(B,).(````/K-`8B=J(A"3?````B<@/K-`0B=J-G"0+`0``B(0D
MX````(G(#ZS0"(B$).$```")\.D+````D(UT)@`/M@>#QP&#[`P/ML!0:/3B
M!`AJ_VH!58/%`NCAO/__@\0@.=UUVL:$)`L!````:$7C!`B-A"3G````4&C<
MX00(_W0D%&@1XP0(:O]J`?]T)"CHJKS__X/$(.G$^?__BP0DBV@$A>T/A`3Y
M__^#[`Q5Z(NZ__^#Q!"#^`,/AN_X__^-=`7\OPSC!`BY!0```/.F#X79^/__
MB>OITOC__[@_````*=")P8V$%($```"#^02-4`AS;H7)=`WVP0+&0`@`#X4_
M`0``C40D4.A@O___C90DB````+D.````,<")U_.KZ5#]___'00@`````@\$,
MQT00_`````"#X?PIR@'"@^+\@_H$#X(K_?__@^+\,<#'!`$`````@\`$.=!R
M\ND3_?__C7@,QT`(`````(G0QT01_`````"#Y_PI^`'(@^#\@_@$<H"#X/R)
MP3'`QP0'`````(/`!#G(<O+I9O___X"\)`X!``!!#X6/^?__@+PD#P$``$,/
MA8'Y__^`O"00`0``2`^%<_G__X"\)!$!``!%#X5E^?__:@)J_VK&BW0D#%;H
MI[C__X/$#&HIC80D%`$``%!6Z$2W__]H1>,$"(V$)"`!``!0:-SA!`C_="0D
M:!'C!`AJ_VH!_W0D..@<N___@\0PZ3;X__^-="8`BP0DBQCI.O?__S')9HE,
M$/[I,?S__S'_9HE\$?[IM?[__^B)M___B?:-O"<`````55=64X/L*&6A%```
M`(E$)!@QP/\U2$$%".ARNO__C50D&,9`80&X_^$$".A0Y/__@\00A<!T"8`X
M,0^$4`(``.C+[___@^P,_S5(004(Z#VZ__]J"VH!:#_C!`A0Z!ZX__^#Q""%
MP`^$LP```(,]B%$%"`&+0`R+>!@/CJ`````Q]KL!````ZS&-M"8`````BT4,
M@^P(4*&$404(_S28Z"RV__^#Q!"%P'5EH8A1!0B#PP&#Q@$YV'Y;@^P,_S5(
M004(Z,BY__]J`%974.@NN?__@\0@A<!T-XLHBT4()0`$(``]``0``'2F@^P,
M_S5(004(Z)BY__]J`FH`55#H[;;__X/$(.N+D(VT)@````"AB%$%"(U0_SGR
M#X0P`0``@^P,_S5(004(Z&*Y__]J`VH!:$3C!`A0Z$.W__^#Q""%P(G#=#2+
M0`R#[`R+,/\U2$$%".@WN?__@\0,:$;C!`A64.AXMO__BT,,@\00BQCV0PI`
M#X40`@``@^P,_S5(004(Z`BY__]J`VH!:$OB!`A0Z.FV__^#Q""%P(G&=#F-
M5"0(N,WA!`CHTN+__X7`B<,/A&@!``"+1@R#[`R+./\U2$$%".C%N/__@\0,
M4U=0Z`JV__^#Q!"#[`S_-4A!!0CHJ;C__XU4)!C&0&$`N,3A!`CHA^+__X/$
M$(7`B<.CC%$%"`^$E0```(/L"&C``0``4.@GM___C5`!@\00@_H!=@F#^!$/
MA8X!``"+1"0,93,%%`````^%>`$``(/$'%M>7UW#C78`C;PG`````(/X`0^.
MQ_[__[L!````9I"#[`S_-4A!!0B#PP'H'[C__UY=5U#HMK3__X/$$#D=B%$%
M"'_;Z9;^__^-M@````"`>`$`#X2K_?__Z:']__^0@^P,_S6$404(Z/+P__^#
MQ!"%P*.,404(#X3K````BT8,BSV$404(BQB+0P@E``0@`#T`!```#X6-````
MBT,,@^P(5U#HU[3__XG'BT8,@\00BQB+4PB!X@`$(`"!^@`$``!U1XM##%=0
MH811!0C_,&@TY`0(Z`:V__^-M@````"AA%$%"(/L#(LXBT8,BQC_-4A!!0CH
M5K?__XGZB=CHW>?__X/$$.F._O__@^P,_S5(004(Z#>W__]J`FH`4U#HC+3_
M_X/$(.N>@^P,_S5(004(Z!FW__]J`FH`4U#H;K3__X/$(.E5____@^P,_S5(
M004(Z/BV__]:65-0Z/^U__^#Q!#IT?W__X/L#&@0Y`0(Z&JU___HQ;/__U"A
MA%$%"%/_,&A<Y`0(Z%*U__]FD%93@^P0BW0D'%;H0>O__P^V"(/$$(G#A,ET
M((U0`>L*#[8*@\(!A,ET$8#Y+W7Q#[8*B=.#P@&$R77OZ,#M__^%P'0>A?9T
M&H`^`'05@^P(:/GB!`A3Z)6R__^#Q!`YV'0&@\0$6U[#@\0$B?!;7NE\X___
MC;8`````C;\`````@^P8_S5(004(Z#*V__]:66K_4.BHL___6/\U2$$%".@<
MMO__@\0,:@!H,,4$"%#HW+7__X/$',-FD&:09I!FD%/HJKC__X'#6E\``(/L
M&(N#'`$``(E$)`R+1"0HB40D"(M$)"2)1"0$BT0D((D$).A;L___@\086\-F
MD&:09I!55S'_5E/H9;C__X'#%5\``(/L'(ML)#"-L^3^___HD;'__XV#X/[_
M_RG&P?X"A?9T)XVV`````(M$)#B)+"2)1"0(BT0D-(E$)`3_E+O@_O__@\<!
M.?=UWX/$'%M>7UW#ZPV0D)"0D)"0D)"0D)"0\\,``%.#[`CH\[?__X'#HUX`
M`(/$"%O#`P````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!0
M05)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`
M4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!0
M05)?0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0
M051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R
M>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`+64`+2T`
M````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```'!E<FQX<VDN
M8P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M```E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@
M,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE
M("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%
M1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@
M*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]
M("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D
M14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*
M96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O
M7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D
M92A?1D@I.PIM>2`D8G5F.PIS965K(%]&2"P@+3@L(#(["G)E860@7T9(+"`D
M8G5F+"`X.PIL87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*<V5E
M:R!?1D@L("TQ,BP@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M
M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T
M.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT
M+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U
M="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.
M5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I
M92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D
M;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I
M<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]
M("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E
M9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R
M:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I
M;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM
M;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E
M("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@
M0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!S;W)T('L*;&5N9W1H
M*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA+T)31%!!3B\*?2!G<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*+UY?/"@N*RDD+R!A;F0@
M+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B1F:6QE<WLD
M7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I
M<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@
M)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=
M*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H
M(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F
M:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC
M;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT
M*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I
M;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF
M("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO
M=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M
M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\
M(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F
M:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<
M,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B
M(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D
M9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M
M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N
M86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D
M14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL
M96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T
M=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO
M<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?
M9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L
M971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT[
M"GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#
M3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@
M;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A
M;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````````
M@/___\]!`1L#.^@````<````$'+__P0!``!0=O__]`T``'!Y__\H`0``X)__
M_VP!``"0H/__T`$``!"A___T`0``(*/__W0"``"`I/__+`,``."E__^X`P``
M@*;__Q0$``!`I___L`0``'"G___8!```P*?__Q`%``"`J/__G`4``)"H__^P
M!0``4*K__ZP&``"`JO__P`8``'"K__\@!P``,*W__U`'``"@K?__;`<``-"M
M__^0!P```*___P`(``!@N___X`L``#"___]P#0``L+___[P-``#PO___-`X`
M`##`__]4#@``H,#__Y`.```4``````````%Z4@`!?`@!&PP$!(@!```@````
M'`````1Q__]`!`````X(1@X,2@\+=`1X`#\:.RHR)")`````0````$!X__]C
M)@```$$."(4"00X,AP-##A"&!$$.%(,%1@Z@!@--)@H.%$'##A!!Q@X,0<<.
M"$'%#@1!"P```&````"$````;)[__Z8`````20X(A0)!#@R'`T$.$(8$00X4
M@P5##C`"1`XT00XX00X\00Y`2`XP5PH.%$/##A!!Q@X,0<<."$'%#@1%"UH.
M%$7##A!!Q@X,0<<."$'%#@0````@````Z````+B>__]R`````$$."(,"10X@
M`F4*#@A!PPX$00M\````#`$``!2?__\0`@```$$."(4"00X,AP-##A"&!$$.
M%(,%10Y,5PY02`Y`6@Y,00Y02`Y``DL.3$<.4$H.0`)L"@X40<,.$$'&#@Q!
MQPX(0<4.!$<+`DX.2$$.3$$.4$@.0&\.3$L.4$@.0$X.1$$.2$D.3$4.4$P.
M0````+0```",`0``I*#__U8!````00X(A0)!#@R'`T$.$(8$00X4@P5(#J`!
M;`H.%$'##A!!Q@X,0<<."$'%#@1$"T,.K`%!#K`!2`Z@`4\.K`%!#K`!2`Z@
M`5<.K`%$#K`!9`ZL`4$.J`%!#JP!00ZP`44.M`%"#K@!0@Z\`4$.P`%(#J0!
M10ZH`4$.K`%"#K`!2`Z@`5@.K`%!#K`!2`Z@`4,.K`%!#K`!2`Z@`78.K`%!
M#K`!4`Z@`0"(````1`(``$RA__]=`0```$$."(8"00X,@P-##AQ&#B!,#AQ)
M#B!*#AQ&#B!9#AQ&#B!/#AQ&#B!(#A1"#AA%#AQ!#B!)#AQ&#B!/#AQ&#B!/
M#AQ&#B!,#AQ)#B!.#A!)#AQ&#B!.#A!&#AQ)#B!6#AQ&#B!6#AQ&#B!,#AQ)
M#B!1#@Q!PPX(0<8.!%@```#0`@``(*+__YD`````00X(@P)%#AQ&#B!.#A1!
M#AA!#AQ"#B!(#A!'"@X(0\,.!$@+0PX<1@X@3@X03PX<1@X@3@X03PX80@X<
M00X@2`X02`X(1,,.!```F````"P#``!DHO__NP````!!#@B%`D$.#(<#0PX0
MA@1!#A2#!4@.M"!4#K@@10Z\($4.P"!(#K`@4PZT($$.N"!"#KP@00[`($@.
ML"!'#KP@1@[`($8.Q"!!#L@@00[,($$.T"!(#K`@5@H.%$'##A!!Q@X,0<<.
M"$'%#@1%"TL.O"!&#L`@2`ZT($$.N"!!#KP@00[`($@.L"``)````,@#``"(
MHO__)P````!##AQ&#B!*#B1%#BA%#BQ!#C!(#@0``#0```#P`P``D*+__T0`
M````0PX<1@X@3@X<1@X@1@X<00X80@X<10X@10XD10XH10XL00XP2`X$B```
M`"@$``"HHO__L0````!!#@B'`D$.#(8#00X0@P1&#J!`5PZH0$4.K$!!#K!`
M10ZT0$4.N$!"#KQ`10[`0$@.H$!'#J1`10ZH0$@.K$!!#K!`2`Z@0$P.K$!!
M#K!`2`Z@0$D.I$!!#JA`00ZL0$$.L$!,#J!`6`H.$$'##@Q!Q@X(0<<.!$0+
M```0````M`0``-RB__\%`````````/@```#(!```V*+__[P!````00X(A0)!
M#@R'`T$.$(8$00X4@P5&#L`@;@[(($0.S"!!#M`@2`[`(&P*#A1!PPX00<8.
M#$''#@A!Q0X$00M##LP@00[0($8.S"!!#L@@20[,($$.T"!(#L`@:P[(($$.
MS"!!#M`@2`[`($L.S"!!#M`@2`[`('$.Q"!!#L@@10[,($$.T"!%#M0@10[8
M($(.W"!!#N`@2`[,($8.T"!(#L0@1@[(($$.S"!"#M`@2`[`($<.S"!&#M`@
M3@[`($\.R"!%#LP@0@[0($@.P"!*#L@@0@[,($$.T"!(#L`@4P[,($$.T"!(
M#L`@`!````#$!0``G*/__RT`````````7````-@%``"XH___Z`````!!#@B#
M`D,.(%8.+$$.,$P.(`)$#BQ"#C!(#B!/"@X(0<,.!$L+80XD00XH00XL10XP
M2`X@2`H."$'##@1'"T,*#@A#PPX$00M+#@A!PPX$+````#@&``!(I/__MP$`
M``!!#@B'`D$.#(8#0PY``UL!"@X,0<8."$''#@1&"P``&````&@&``#8I?__
M:0````!##B!F"@X$1PL``"````"$!@``+*;__R0`````0PX02`X<00X@2`X0
M20H.!$,+`&P```"H!@``.*;__R8!````00X(A0)!#@R'`T8.$(8$00X4@P5(
M#F`"4@YH00YL00YP3`Y@`D(*#A1!PPX00<8.#$''#@A!Q0X$20M##FQ!#G!L
M#F1%#FA%#FQ!#G!%#G1"#GA"#GQ!#H`!3`Y@``#<`P``&`<``/BF__]7#```
M`$$."(4"00X,AP-!#A"&!$$.%(,%1@ZP@@("I@Z\@@)!#L""`DP.L(("0PZ\
M@@)!#L""`D@.L(("50Z\@@)$#L""`D4.Q(("0@[(@@)"#LR"`D$.T(("2PZP
M@@("0PZ\@@)!#L""`D@.L(("`D,.O(("00[`@@)(#K""`E8.O(("0P[`@@)(
M#K""`FT.O(("2@[`@@)*#L2"`D<.R(("10[,@@)!#M""`D4.U(("0@[8@@)"
M#MR"`D$.X(("2`ZX@@)%#KR"`D$.P(("2`ZP@@)(#KR"`D8.P(("2`ZT@@)&
M#KB"`D0.O(("0@[`@@)(#K""`D<.O(("1`[`@@)&#L2"`D4.R(("0@[,@@)&
M#M""`D@.L(("7`H.%$'##A!!Q@X,0<<."$'%#@1""T\*#KB"`D$.O(("1`[`
M@@)&#L2"`D4.R(("20M##KR"`D8.P(("3@ZP@@)3#KR"`D8.P(("4PZP@@)+
M#KR"`D8.P(("3@ZP@@)3#KR"`D$.P(("6@ZP@@)+#KR"`D$.P(("1@Z\@@)!
M#KB"`D$.O(("1@[`@@)(#K""`DT.O(("00[`@@)(#K""`GP.N(("0@Z\@@)!
M#L""`DP.L(("8PZT@@)!#KB"`D4.O(("10[`@@)%#L2"`D(.R(("0@[,@@)%
M#M""`D@.L(("7@Z\@@)%#L""`D$.Q(("00[(@@)%#LR"`D$.T(("10[4@@)"
M#MB"`D(.W(("00[@@@)(#K""`D,.N(("10Z\@@)!#L""`D@.L(("2`Z\@@)$
M#L""`F`.L(("2@Z\@@)!#L""`E@.L(("=`Z\@@)!#L""`D@.L(("60ZT@@)"
M#KB"`D(.O(("10[`@@)(#K2"`D(.N(("2`Z\@@)!#L""`D@.L(("6@ZT@@)"
M#KB"`D(.O(("1`[`@@("E0ZP@@)&#K2"`D4.N(("2`Z\@@)$#L""`D@.L(("
M`HP.M(("00ZX@@)(#KR"`D$.P(("6`ZP@@(#!`$.M(("00ZX@@)!#KR"`D@.
MP(("3PZP@@)U#KR"`D0.P(("`D0.L(("`P4"#KR"`D0.P(("10[$@@)"#LB"
M`D(.S(("00[0@@)+#K""`E$.M(("2`ZX@@)%#KR"`D0.P(("10[$@@)"#LB"
M`D(.S(("1`[0@@)(#K""`E8.O(("00[`@@)(#K""`@,C`0ZT@@)"#KB"`D(.
MO(("10[`@@)(#K2"`D(.N(("2`Z\@@)!#L""`DH.Q(("2`[(@@)%#LR"`D0.
MT(("10[4@@)"#MB"`D(.W(("1`[@@@)(#K""`@```(P!``#X"@``>*___\X#
M````00X(A0)!#@R'`T$.$(8$00X4@P5##CQ2#D!:#C!5#CQ&#D!'#D1"#DA%
M#DQ!#E!(#C!Q#CA!#CQ(#D!(#C!6#CQ&#D!'#D1!#DA!#DQ!#E!(#C!8#CQ&
M#D!'#D1"#DA!#DQ!#E!(#C!=#CQ&#D!'#D1"#DA%#DQ!#E!(#C!,#CQ(#D!(
M#C1%#CA!#CQ!#D!+#C!/#CQ&#D!'#D1"#DA%#DQ!#E!(#C!D#CQ(#D!(#C1!
M#CA!#CQ!#D!(#C!##CQ&#D!:#C!2#CA%#CQ!#D!+#C!B"@X40<,.$$'&#@Q!
MQPX(0<4.!$L+4PX\1@Y`20X\00XX00X\00Y`2`XP9@X\1@Y`2`XP<0XX00X\
M00Y`30XP5PH.-$$..$<./$4.0$L+2`X\30Y`40XP2`X\1@Y`1PY$0@Y(00Y,
M00Y02`XP10X\1@Y`1PY$0@Y(00Y,00Y02`XP2`X\1@Y`1@X\00XX00X\00Y`
M2`XP2`H./$4.0$4+1@XT1@XX0@X\10Y```!(````B`P``+BQ__]T`````$$.
M"(8"00X,@P-##AQ%#B!+#A![#AA%#AQ!#B!(#A!'"@X,0<,."$'&#@1!"T,.
M#$/##@A!Q@X$````-````-0,``#LL?__.`````!##AQ&#B!&#AQ!#AA"#AQ!
M#B!&#AQ&#B!(#A1"#AA%#AQ!#B!(#@0\````#`T``%1H__\B`@```$0,`0!'
M$`4"=0!%#P-U=`80!@)U?!`#`G5X`Z,!"L$,`0!!PT'&0<5##`0$00L`'```
M`$P-``"TL?__.@````!!#@B#`DX.(&D."$'##@0X````;`T``-2Q__]A````
M`$$."(4"00X,AP-##A"&!$$.%(,%3@XP`D@.%$'##A!!Q@X,0<<."$'%#@00
M````J`T```BR__\"````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````\)D$"-"9
M!`@``````0````$````!````!0(```$````0`@```0```!H"```!````:0(`
M``$```"^`P``#````)22!`@-````5.$$"!D```#@/@4(&P````0````:````
MY#X%"!P````$````]?[_;ZR!!`@%````J(D$"`8````(@P0("@```$`%```+
M````$````!4``````````P````!`!0@"````&`(``!0````1````%P```'R0
M!`@1````3)`$"!(````P````$P````@```#^__]OO(\$"/___V\"````\/__
M;^B.!`@`````````````````````````````````````````````````````
M````````````````[#X%"```````````UI($".:2!`CVD@0(!I,$"!:3!`@F
MDP0(-I,$"$:3!`A6DP0(9I,$"':3!`B&DP0(EI,$"*:3!`BVDP0(QI,$"-:3
M!`CFDP0(]I,$"`:4!`@6E`0()I0$"#:4!`A&E`0(5I0$"&:4!`AVE`0(AI0$
M"):4!`BFE`0(MI0$",:4!`C6E`0(YI0$"/:4!`@&E00(%I4$"":5!`@VE00(
M1I4$"%:5!`AFE00(=I4$"(:5!`B6E00(II4$"+:5!`C&E00(UI4$".:5!`CV
ME00(!I8$"!:6!`@FE@0(-I8$"$:6!`A6E@0(9I8$"':6!`B&E@0(EI8$"*:6
M!`BVE@0(QI8$"-:6!`CFE@0(]I8$"```````````_____Z#D!`A'0T,Z("A$
M96)I86X@-"XY+C(M,3`I(#0N.2XR`$=#0SH@*$1E8FEA;B`T+C@N-"TQ*2`T
M+C@N-```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG
M;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E
M<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O
M="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````
M```````````````````````````````````+`````0````(```!4@00(5`$`
M`!,```````````````$`````````$P````<````"````:($$"&@!```@````
M```````````$`````````"$````'`````@```(B!!`B(`0``)```````````
M````!``````````T````]O__;P(```"L@00(K`$``%P!```%``````````0`
M```$````/@````L````"````"(,$"`@#``"@!@``!@````$````$````$```
M`$8````#`````@```*B)!`BH"0``0`4``````````````0````````!.````
M____;P(```#HC@0(Z`X``-0````%``````````(````"````6P```/[__V\"
M````O(\$"+P/``"0````!@````(````$`````````&H````)`````@```$R0
M!`A,$```,`````4`````````!`````@```!S````"0```$(```!\D`0(?!``
M`!@"```%````#`````0````(````?`````$````&````E)($")02```C````
M```````````$`````````'<````!````!@```,"2!`C`$@``0`0`````````
M````$`````0```""`````0````8`````EP0(`!<``%)*`````````````!``
M````````B`````$````&````5.$$"%1A```4```````````````$````````
M`(X````!`````@```&CA!`AH80``2#\`````````````"`````````"6````
M`0````(```"P(`4(L*```.P```````````````0`````````I`````$````"
M````G"$%")RA``"\#0`````````````$`````````*X````.`````P```.`^
M!0C@O@``!```````````````!`````````"Z````#P````,```#D/@4(Y+X`
M``0```````````````0`````````Q@````$````#````Z#X%".B^```$````
M```````````$`````````,L````&`````P```.P^!0CLO@``$`$```8`````
M````!`````@```#4`````0````,```#\/P4(_+\```0```````````````0`
M```$````V0````$````#`````$`%"`#````8`0`````````````$````!```
M`.(````!`````P```!A!!0@8P0``$```````````````!`````````#H````
M"`````,```!`004(*,$``%00`````````````$``````````[0````$````P
M`````````"C!```Y```````````````!`````0````$````#````````````
:``!AP0``]@```````````````0``````````
